/*
 *  Copyright (c) 2004 on behalf of the EU EGEE Project:
 *  The European Organization for Nuclear Research (CERN),
 *  Istituto Nazionale di Fisica Nucleare (INFN), Italy
 *  Datamat Spa, Italy
 *  Centre National de la Recherche Scientifique (CNRS), France
 *  CS Systeme d'Information (CSSI), France
 *  Royal Institute of Technology, Center for Parallel Computers (KTH-PDC), Sweden
 *  Universiteit van Amsterdam (UvA), Netherlands
 *  University of Helsinki (UH.HIP), Finland
 *  University of Bergen (UiB), Norway
 *  Council for the Central Laboratory of the Research Councils (CCLRC), United Kingdom
 */
#ifndef CONSUMERFACTORYIMPL_H
#define CONSUMERFACTORYIMPL_H
#include "rgma/ConsumerFactory.h"
#include "rgma/TimeInterval.h"
#include "rgma/QueryProperties.h"
#include "rgma/Consumer.h"
#include "rgma/StringList.h"
#include "rgma/RemoteException.h"
#include "rgma/RGMAException.h"
#include "rgma/UnknownResourceException.h"
#include "rgma/ResourceEndpoint.h"
#include <string>

using glite::rgma::ConsumerFactory;
using glite::rgma::Consumer;
using glite::rgma::StringList;
using glite::rgma::TimeInterval;
using glite::rgma::ResourceEndpoint;
using glite::rgma::UnknownResourceException;
using glite::rgma::QueryProperties;
using glite::rgma::RemoteException;
using glite::rgma::RGMAException;

namespace rgma
{
    namespace impl
    {
        /**
         * 
         * Implementation of the ConsumerFactory interface
         * 
         */
        class ConsumerFactoryImpl : virtual public ConsumerFactory
        {
            public:

                ConsumerFactoryImpl();
                virtual ~ConsumerFactoryImpl();
                /**
                 * Creates a consumer with a specific SELECT query and query type. The
                 * Consumer will only consume data from the VO's listed in
                 * <code>voNames</code>.
                 *
                 * @param terminationInterval The interval after which this Consumer will
                 *        be removed from the remote service if there has been no contact
                 *        from the API.
                 * @param selectStatement An SQL SELECT statement.
                 * @param queryType The type of the query.
                 * @param voNames List of VO names to consume from.
                 *
                 * @return A pointer to a new Consumer.
                 *
                 * @throws RemoteException If the service could not be contacted.
                 * @throws RGMAException If the select statement is invalid.  If no endpointReference is defined in
                 *         properties.
                 */
                Consumer* createConsumer(TimeInterval terminationInterval,
                    std::string selectStatement, QueryProperties queryProperties)
                    throw(RemoteException, RGMAException);
                /**
                 * Reconnects to an existing Consumer and checks that it is still active
                 * by sending a showSignOfLife call.
                 *
                 * @param resourceEndpoint Endpoint of the consumer.
                 *
                 * @return A reference to the Consumer.
                 */
                Consumer* reconnectConsumer(ResourceEndpoint& resourceEndpoint)
                    throw(RGMAException, RemoteException, UnknownResourceException);
        };
    }
}
#endif                                            // CONSUMERFACTORYIMPL_H
