/*
 *  Copyright (c) 2004 on behalf of the EU EGEE Project:
 *  The European Organization for Nuclear Research (CERN),
 *  Istituto Nazionale di Fisica Nucleare (INFN), Italy
 *  Datamat Spa, Italy
 *  Centre National de la Recherche Scientifique (CNRS), France
 *  CS Systeme d'Information (CSSI), France
 *  Royal Institute of Technology, Center for Parallel Computers (KTH-PDC), Sweden
 *  Universiteit van Amsterdam (UvA), Netherlands
 *  University of Helsinki (UH.HIP), Finland
 *  University of Bergen (UiB), Norway
 *  Council for the Central Laboratory of the Research Councils (CCLRC), United Kingdom
 */
#ifndef COLUMNDEFINITION_H
#define COLUMNDEFINITION_H

#include <string>

namespace glite
{
    namespace rgma
    {
        /**
         * Definition of a column in an SQL CREATE TABLE statement.
         */
        class ColumnDefinition
        {
            public:
                /**
                 * Creates a new ColumnDefinition object.
                 */
                ColumnDefinition(std::string columnName, std::string type,
                    int size, bool isNotNull, bool isPrimaryKey);

                virtual ~ColumnDefinition(){}
                /**
                 * Creates a new ColumnDefinition object.
                 */
                ColumnDefinition( const ColumnDefinition& type );
                ColumnDefinition& operator=(const ColumnDefinition& type );
                bool operator==(const ColumnDefinition& type );
                /**
                 * Sets the name.
                 *
                 * @param name The name to set
                 */
                void setName(std::string name);

                /**
                 * Returns the name.
                 *
                 * @return String
                 */
                std::string getName();

                /**
                 * Sets the NOT NULL flag.
                 *
                 * @param notNull The value to set.
                 */
                void setNotNull(bool notNull);

                /**
                 * Returns the NOT NULL flag.
                 *
                 * @return boolean
                 */
                bool isNotNull();

                /**
                 * Sets the PRIMARY KEY flag.
                 *
                 * @param primaryKey The value to set.
                 */
                void setPrimaryKey(bool primaryKey);

                /**
                 * Returns the PRIMARY KEY flag.
                 *
                 * @return boolean
                 */
                bool isPrimaryKey();

                /**
                 * Sets the type.
                 *
                 * @param type The type to set
                 */
                void setType(std::string type);

                /**
                 * Returns the type.
                 *
                 * @return String
                 */
                std::string getType();

                /**
                 * @return Returns the size for CHAR and VARCHAR types.
                 */
                int getSize();

                /**
                 * @return True if the column type has an associated
                 * size &gt 0.
                 */
                bool containsValidSize();

            private:
                /**
                 * Column name.
                 */
                std::string m_name;

                /**
                 * Column width for CHAR and VARCHAR types.
                 */
                int m_size;

                /**
                 * Column type (name).
                 */
                std::string m_type;

                /**
                 * NOT NULL flag.
                 */
                bool m_notNull;

                /**
                 * PRIMARY KEY flag.
                 */
                bool m_primaryKey;

        };
        std::ostream& operator<<( std::ostream& stream, ColumnDefinition colDef );
    }
}
#endif
