/*
 *  Copyright (c) 2004 on behalf of the EU EGEE Project:
 *  The European Organization for Nuclear Research (CERN),
 *  Istituto Nazionale di Fisica Nucleare (INFN), Italy
 *  Datamat Spa, Italy
 *  Centre National de la Recherche Scientifique (CNRS), France
 *  CS Systeme d'Information (CSSI), France
 *  Royal Institute of Technology, Center for Parallel Computers (KTH-PDC), Sweden
 *  Universiteit van Amsterdam (UvA), Netherlands
 *  University of Helsinki (UH.HIP), Finland
 *  University of Bergen (UiB), Norway
 *  Council for the Central Laboratory of the Research Councils (CCLRC), United Kingdom
 */
#ifndef COLUMNDEFINITIONLIST_H
#define COLUMNDEFINITIONLIST_H

#include "rgma/ColumnDefinition.h"
#include <vector>

#include <string>

namespace glite
{
    namespace rgma
    {
        /**
         * Contains a list of column definitions.
         */
        class ColumnDefinitionList
        {
            public:
                /**
                 * Creates a new column definition list.
                 */
                ColumnDefinitionList();
                ~ColumnDefinitionList(){}

                /**
                 * get a cloumn definition at a specific location in the list
                 *
                 * @param index the index of the ColumnDefinition to get (0 &lt;= index &lt; size)
                 * @return the CloumnDefinition located at index
                 */
                ColumnDefinition getColumnDefinition( int index );
                /**
                 * add a definition to the list
                 *
                 * @param def the Definition to add to the list
                 *
                 */
                void add( ColumnDefinition def );
                ColumnDefinitionList( const ColumnDefinitionList& list );
                ColumnDefinitionList& operator=(const ColumnDefinitionList& list  );
                /**
                 * @return the number of definitions in the list
                 *
                 */
                int size();

            private:
                std::vector<ColumnDefinition> m_defList;
        };
        std::ostream& operator<<( std::ostream& stream, ColumnDefinitionList colDefList);
    }
}
#endif
