/* Copyright (c) 2003 EU DataGrid. */
/* For license conditions see http://www.eu-datagrid.org/license.html */

#ifndef RGMA_ENVIRONMENT_H
#define RGMA_ENVIRONMENT_H

#include <semaphore.h>
#include <string>
#include <vector>

namespace glite
{
    namespace rgma
    {

        /**
         * Static class defines the R-GMA specific variables if necessary.  R-GMA C++
         * functions read their environment variables via a call to Environment::getenv()
         * which does the setup if necessary.
         */
        class Environment
        {

            public:

                /**
                 * Gets the value for the specified environment variable.
                 * The first time that it is called, it checks if the RGMA_HOME environment
                 * variable is defined.  If not then it the scripts and defines it from the
                 * values specified in the scripts.  It also defines the other R-GMA variables
                 * which are not defined.  It does none of this if RGMA_HOME is not defined.
                 */
                static const char* getenv(const std::string& name);

            private:

                struct VariableFromScript
                {
                    std::string name;
                    char* value;
                    VariableFromScript(std::string name) : name(name), value(0) {}
                };

                /**
                 * Run scripts and set R-GMA-specific environment variables from them.
                 */
                static void setupEnvironmentFromScripts();

                static bool environmentSetUp;
                static sem_t settingUpLock;
                static int semInitStatus;
                static const class APILogging& cat;
        };
    }                                             // rgma
}                                                 // glite
#endif                                            //glite_ENVIRONMENT_H
