/*
 *  Copyright (c) 2004 on behalf of the EU EGEE Project:
 *  The European Organization for Nuclear Research (CERN),
 *  Istituto Nazionale di Fisica Nucleare (INFN), Italy
 *  Datamat Spa, Italy
 *  Centre National de la Recherche Scientifique (CNRS), France
 *  CS Systeme d'Information (CSSI), France
 *  Royal Institute of Technology, Center for Parallel Computers (KTH-PDC), Sweden
 *  Universiteit van Amsterdam (UvA), Netherlands
 *  University of Helsinki (UH.HIP), Finland
 *  University of Bergen (UiB), Norway
 *  Council for the Central Laboratory of the Research Councils (CCLRC), United Kingdom
 */
#ifndef EXCEPTIONBASE_H
#define EXCEPTIONBASE_H
#include <exception>
#include <string>

namespace glite
{
    namespace rgma
    {
        /**
         * Base Class from which all RGMA based exceptions are extended
         * this will allow for nested exeptions.
         */
        class ExceptionBase : public std::exception
        {
            protected:
                std::string m_message;
                int m_errNo;
                ExceptionBase* m_cause;
                std::string m_sourceIdentifier;

            public:

                ExceptionBase();
                virtual ~ExceptionBase()throw();
                /**
                 * Getter for any nested exceptions
                 * @return the nested exception
                 */
                ExceptionBase* getCause() const;

                /**
                 * Getter for message
                 * @return the message
                 */
                std::string getMessage() const;
                /**
                 * Getter for error number
                 * @return the error number
                 */
                int getErrNo() const;
                /**
                 * The source at which the error occurred.
                 * @return the the source at which the error occured
                 */
                std::string getSourceIdentifier() const;
                /**
                 * cleanup any nested exceptions
                 */
                void cleanUp();
                /**
               * Return descriptive message
               */
              const char* what() const throw();
        };
    }
}
#endif                                            // EXCEPTIONBASE_H
