/*
 *  Copyright (c) 2004 on behalf of the EU EGEE Project:
 *  The European Organization for Nuclear Research (CERN),
 *  Istituto Nazionale di Fisica Nucleare (INFN), Italy
 *  Datamat Spa, Italy
 *  Centre National de la Recherche Scientifique (CNRS), France
 *  CS Systeme d'Information (CSSI), France
 *  Royal Institute of Technology, Center for Parallel Computers (KTH-PDC), Sweden
 *  Universiteit van Amsterdam (UvA), Netherlands
 *  University of Helsinki (UH.HIP), Finland
 *  University of Bergen (UiB), Norway
 *  Council for the Central Laboratory of the Research Councils (CCLRC), United Kingdom
 */
#ifndef INDEX_H
#define INDEX_H

#include <vector>
#include <string>

namespace glite
{
    namespace rgma
    {
        /**
         * An index on a table.
         */
        class Index
        {
            public:
                /**
                 * Creates a new Index object.
                 */
                Index(std::string indexName, std::vector<std::string> columnNames);
                Index( const Index& index );
                Index& operator=(const Index& index );

                virtual ~Index(){}
                /**
                 * Returns the name.
                 *
                 * @return String
                 */
                std::string getName();

                /**
                 * Returns the name of the given column used by this index.
                 *
                 * @param columnNumber Number of the column (0..numColumns-1)
                 *
                 * @return Name associated with the given column number.
                 */
                std::string getColumnName(int columnNumber);
                /**
                 * Returns the List of column names used by this index.
                 *
                 * @return List of column names.
                 */
                std::vector<std::string> getColumnNames();

                /**
                 * Returns the number of columns in the index.
                 *
                 * @return number of columns.
                 */
                int size();

            private:
                /**
                 * Index name.
                 */
                std::string m_name;

                std::vector<std::string> m_columnNames;

        };
        std::ostream& operator<<( std::ostream& stream, Index index);
    }
}
#endif
