#ifndef ONDEMANDPRODUCERIMPL_H
#define ONDEMANDPRODUCERIMPL_H

#include "rgma/ResourceImpl.h"
#include "rgma/RemoteException.h"
#include "rgma/UnknownResourceException.h"
#include "rgma/RGMAException.h"
#include "rgma/OnDemandProducer.h"
#include "rgma/TimeInterval.h"
#include "rgma/URI.h"
#include "rgma/StringList.h"
#include <string>

namespace glite
{
    namespace rgma
    {
        /**
         * Implementation of an on demand producer
         */
        class OnDemandProducerImpl : public OnDemandProducer
        {
            public:
                /**
                 * @deprecated use OnDemandProducerImpl(TimeInterval terminationInterval,
                 *                  URI uri)throw( RGMAException );
                 * */
                OnDemandProducerImpl(TimeInterval terminationInterval,
                    URI uri,
                    StringList voNames)throw( RGMAException);

                OnDemandProducerImpl(TimeInterval terminationInterval,
                    URI uri)throw( RGMAException, RemoteException);

                OnDemandProducerImpl(ResourceEndpoint& endPoint)throw( RGMAException, RemoteException);
                ~OnDemandProducerImpl(){}
                /**
                 * Declares a static table into which this Producer can publish.  A subset
                 * of a table can be declared using a predicate.  A static table has no
                 * MeasurementDate/Time associated with each tuple.
                 *
                 * @param tableName The name of the table to publish into.
                 * @param predicate An SQL WHERE clause defining the subset of a table that
                 *        this Producer will publish.  To publish to the whole table, an
                 *        empty predicate can be defined using "".
                 *
                 * @throws RemoteException If the service could not be contacted.
                 * @throws UnknownResourceException If the producer resource could not be
                 *         found
                 * @throws RGMAException If table <code>tableName</code> is not in the
                 *         Schema. If the predicate is invalid.
                 */
                virtual void declareStaticTable(std::string tableName, std::string predicate)
                    throw(RemoteException, RGMAException, UnknownResourceException);
            private:
                void createProducer(TimeInterval terminationInterval,
                    URI uri)throw( RGMAException, RemoteException);
        };
    }
}
#endif
