/*
 *  Copyright (c) 2004 on behalf of the EU EGEE Project:
 *  The European Organization for Nuclear Research (CERN),
 *  Istituto Nazionale di Fisica Nucleare (INFN), Italy
 *  Datamat Spa, Italy
 *  Centre National de la Recherche Scientifique (CNRS), France
 *  CS Systeme d'Information (CSSI), France
 *  Royal Institute of Technology, Center for Parallel Computers (KTH-PDC), Sweden
 *  Universiteit van Amsterdam (UvA), Netherlands
 *  University of Helsinki (UH.HIP), Finland
 *  University of Bergen (UiB), Norway
 *  Council for the Central Laboratory of the Research Councils (CCLRC), United Kingdom
 */
#ifndef PRODUCERTABLEENTRY_H
#define PRODUCERTABLEENTRY_H
#include "rgma/ResourceEndpoint.h"
#include "rgma/ProducerType.h"
#include <string>

namespace glite
{
    namespace rgma
    {
        /**
         * Contains producer-table entry from the registry.
         */
        class ProducerTableEntry
        {
            public:
                ProducerTableEntry(ResourceEndpoint endpoint = ResourceEndpoint(), std::string tableName = "",
                    ProducerType producerType = ProducerType(), int hrpSec = 0, std::string qosAttrib = "");
                ~ProducerTableEntry();
                ProducerTableEntry( const ProducerTableEntry& type );
                ProducerTableEntry& operator=(const ProducerTableEntry& type );
                bool operator==(const ProducerTableEntry& type );
                /**
                 * Gets the producer's endpoint.
                 *
                 * @return An Endpoint object.
                 */
                ResourceEndpoint getEndpoint();

                /**
                 * Returns the type of the producer.
                 */
                ProducerType getProducerType();
                /**
                 * Returns the producer's history retention period.
                 */
                int getRetentionPeriod();

                /**
                 * Returns the tableName.
                 */
                std::string getTableName();
                /**
                 * Returns the producer's Quality of Service attribute.
                 */
                std::string getQosAttrib();

            private:
                /**
                 * The producer's endpoint.
                 */
                ResourceEndpoint m_endpoint;

                /**
                 * Producer's table name.
                 */
                std::string m_tableName;

                /**
                 * Producer's type.
                 */
                ProducerType m_producerType;

                /**
                 * History retention period in seconds
                 */
                int m_hrpSec;

                /**
                 * The producer's Quality Of Service attribute.
                 */
                std::string m_qosAttrib;
        };
        std::ostream& operator<<( std::ostream& stream, ProducerTableEntry pte);
    }
}
#endif
