/*
 *  Copyright (c) 2004 on behalf of the EU EGEE Project:
 *  The European Organization for Nuclear Research (CERN),
 *  Istituto Nazionale di Fisica Nucleare (INFN), Italy
 *  Datamat Spa, Italy
 *  Centre National de la Recherche Scientifique (CNRS), France
 *  CS Systeme d'Information (CSSI), France
 *  Royal Institute of Technology, Center for Parallel Computers (KTH-PDC), Sweden
 *  Universiteit van Amsterdam (UvA), Netherlands
 *  University of Helsinki (UH.HIP), Finland
 *  University of Bergen (UiB), Norway
 *  Council for the Central Laboratory of the Research Councils (CCLRC), United Kingdom
 */
#ifndef RGMA_EXCEPTION_H
#define RGMA_EXCEPTION_H

#include "rgma/ExceptionBase.h"
#include <exception>
#include <string>

namespace glite
{
    namespace rgma
    {

        /**
         * RGMAException is an exception that serves
         * descriptive strings through its getMessage() method
         */
        class RGMAException : public ExceptionBase
        {

            public:
                /**
                 *
                 * @param class_name and function where the exeption was thrown from
                 * @param message which describes the error
                 * @param err_no number which represents the error
                 * @param exception any exceptions which have been caught and are being re-thrown
                 */
                RGMAException(std::string sourceIdentifier, std::string message, int err_no, ExceptionBase* cause);
                /**
                 * @param class_name and function where the exeption was thrown from
                 * @param message which describes the error
                 * @param exception any exceptions which have been caught and are being re-thrown
                 */
                RGMAException(std::string class_name = "", std::string message = "", ExceptionBase* cause = NULL);

                /**
                 * Destruct the exception
                 */
                virtual ~RGMAException() throw();

                /**
                 * Returns the number of successful operations (for batch commands).
                 *
                 * @return The number of successful operations (for batch commands).
                 */
                int getNumSuccessfulOps();

                /**
                 * Sets the number of successful operations (for batch commands).
                 *
                 * @param numSuccessfulOps Number of successful operations (for batch commands).
                 */
                void setNumSuccessfulOps(int numSuccessfulOps);

            protected:
                int m_numSuccessfulOps;

        };
    }                                             // rgma
}                                                 // glite
#endif                                            //RGMA_EXCEPTION_H
