/*
 *  Copyright (c) 2004 on behalf of the EU EGEE Project:
 *  The European Organization for Nuclear Research (CERN),
 *  Istituto Nazionale di Fisica Nucleare (INFN), Italy
 *  Datamat Spa, Italy
 *  Centre National de la Recherche Scientifique (CNRS), France
 *  CS Systeme d'Information (CSSI), France
 *  Royal Institute of Technology, Center for Parallel Computers (KTH-PDC), Sweden
 *  Universiteit van Amsterdam (UvA), Netherlands
 *  University of Helsinki (UH.HIP), Finland
 *  University of Bergen (UiB), Norway
 *  Council for the Central Laboratory of the Research Councils (CCLRC), United Kingdom
 */
#ifndef RESOURCE_ENDPOINT_H
#define RESOURCE_ENDPOINT_H

#include <iostream>
#include <string>

namespace glite
{
    namespace rgma
    {
        /**
         * A service or resource endpoint.
         */
        class ResourceEndpoint
        {
            public:
                /**
                 * creates an endpoint object from the given Service URL and resourceId
                 * @param url the service URL of the end point
                 * @param resourceId the resourcid
                 */
                ResourceEndpoint(std::string url = "", int resourceId = 0);
                /**
                 * creates an endpoint object from the given Service URL
                 * @param url the service URL of the end point
                 * @param resourceId the resourcid
                 */
                //ResourceEndpoint(std::string url = "");
                /**
                 * creates a new Endpoint object from the given Endpoint
                 * @param endpoint the endpoint to be copied
                 *
                 */
                ResourceEndpoint(const ResourceEndpoint& endpoint);

                ResourceEndpoint& operator=(const ResourceEndpoint& endpoint);
                bool operator==(const ResourceEndpoint& endpoint);
                virtual ~ResourceEndpoint();

                /**
                 * get the resourceId of this Endpoint
                 * @return the resourceId
                 */
                int getResourceId();
                /**
                 * get the URL of this Endpoint
                 * @return the URL
                 */
                std::string getUrl();
                /**
                 * get the stringified representation of this Endpoint
                 * @return the stringified representation of this Endpoint
                 */
                std::string toString();

                bool equals( const ResourceEndpoint& endpoint );

            private:
                std::string m_url;
                int m_resourceId;
        };

        std::ostream& operator<<( std::ostream& stream, ResourceEndpoint rs );
    }
}
#endif                                            // RESOURCE_ENDPOINT_H
