/*
 *  Copyright (c) 2004 on behalf of the EU EGEE Project:
 *  The European Organization for Nuclear Research (CERN),
 *  Istituto Nazionale di Fisica Nucleare (INFN), Italy
 *  Datamat Spa, Italy
 *  Centre National de la Recherche Scientifique (CNRS), France
 *  CS Systeme d'Information (CSSI), France
 *  Royal Institute of Technology, Center for Parallel Computers (KTH-PDC), Sweden
 *  Universiteit van Amsterdam (UvA), Netherlands
 *  University of Helsinki (UH.HIP), Finland
 *  University of Bergen (UiB), Norway
 *  Council for the Central Laboratory of the Research Councils (CCLRC), United Kingdom
 */
#ifndef RESULTSET_H
#define RESULTSET_H
#include "rgma/StringList.h"
#include "rgma/RGMAWarning.h"
#include "rgma/Tuple.h"
#include "rgma/RGMAException.h"
#include "rgma/ResultSetMetaData.h"
#include <vector>
#include <ostream>

namespace glite
{
    namespace rgma
    {
        /**
         * ResultSet This class must be extended to provice the setter methods
         *
         */
        class ResultSet
        {
            public:

                virtual ~ResultSet();

                /**
                 *
                 * Is this the last one in a possible sequence of results set
                 *
                 *
                 *
                 */
                bool endOfResults();

                /**
                 *
                 * Get any worning provided with the result set
                 *
                 * @return pointer to RGMA Warning
                 *
                 */
                RGMAWarning getWarning();
                /**
                 * an iterator of type vector<Tuple> that is used
                 * to traverse a vector of Tuples after it has been initialised
                 * using the begin() and end() functions.
                 * Can be used with increment ++ operator
                 *
                 */
                typedef std::vector<Tuple>::iterator iterator;
                /**
                 * @return an iterator of type vector<Tuple> which points to
                 * the first element of the Result Set
                 *
                 */
                iterator begin();
                /**
                 * @return an iterator of type vector<Tuple> which points to
                 * the end of the Result Set
                 *
                 */
                iterator end();

                /**
                 * @return number of tuples in result set
                 *
                 */
                int size();

                ResultSet();

                ResultSet(ResultSetMetaData& metaData);

            protected:
                bool m_endOfResults;
                std::vector<Tuple> m_tuples;
                ResultSetMetaData m_metaData;
                RGMAWarning m_warning;

                /**
                 * Set The RGMAWarning.
                 *
                 * @param warning the warning to be set
                 */
                //virtual void setWarning(RGMAWarning warning);
                /**
                 * Set whether this is the end of a set of chunked result sets.
                 *
                 * @param endOfResults
                 */
                //virtual void setEndOfResults( bool endOfResults);
                /**
                 * Adds a row of Tuples to the ResultSet.
                 *
                 * @param tuple a list of TupleItems
                 */
                //virtual void addRow(Tuple tuple);
                /**
                 * Adds the meta data that describes this ResultSet.
                 *
                 * @param metaData the meta data that describes this ResultSet.
                 */
                //virtual void setMetaData( ResultSetMetaData& metaData );

            private:

        };
        std::ostream& operator<<( std::ostream& stream, ResultSet rs );
    }
}
#endif                                            // RESULTSET_H
