/*
 *  Copyright (c) 2004 on behalf of the EU EGEE Project:
 *  The European Organization for Nuclear Research (CERN),
 *  Istituto Nazionale di Fisica Nucleare (INFN), Italy
 *  Datamat Spa, Italy
 *  Centre National de la Recherche Scientifique (CNRS), France
 *  CS Systeme d'Information (CSSI), France
 *  Royal Institute of Technology, Center for Parallel Computers (KTH-PDC), Sweden
 *  Universiteit van Amsterdam (UvA), Netherlands
 *  University of Helsinki (UH.HIP), Finland
 *  University of Bergen (UiB), Norway
 *  Council for the Central Laboratory of the Research Councils (CCLRC), United Kingdom
 */
#ifndef RESULTSETMETADATA_H
#define RESULTSETMETADATA_H

#include <vector>
#include <string>

namespace glite
{
    namespace rgma
    {
        /**
         * Class that contains a list of metadata corresponding to the
         * values held in a Tuple
         *
         */
        class ResultSetMetaData
        {

            public:
                /**
                 *
                 * class that will encapsulate the metadata that is associated with
                 * a result set value
                 *
                 */
                class MetaData
                {
                    private:
                        std::string m_tableName;
                        std::string m_columnName;
                        int m_columnType;

                    public:
                        /**
                         * creates a MetaData object
                         * @param tableName the name of the table from which the value has been retrieved
                         * @param columnName the name of the column from which the value has been retrieved
                         * @param columnType the type of the value see Types.h for valid types
                         */
                        MetaData(std::string tableName, std::string columnName, int columnType);

                        /**
                         * get the table name
                         * @return the table name
                         */
                        std::string getTableName();
                        /**
                         * get the column name
                         * @return the column name
                         */

                        std::string getColumnName();
                        /**
                         * get the column type
                         * @return the column type see Types.h for valid types
                         *
                         */
                        int getColumnType();
                        virtual ~MetaData();
                };
                virtual ~ResultSetMetaData(){}

                ResultSetMetaData( const ResultSetMetaData& metaData );

                ResultSetMetaData& operator=( const ResultSetMetaData& metaData );

                /** iterator to enable iteration over the elements
                 * of Metadata
                 *
                 */
                typedef std::vector<MetaData>::iterator iterator;
                /**
                 * @return an iterator of type vector<MetaData> which points
                 * to the first element of MetaData
                 *
                 */
                iterator begin();
                /**
                 * @return an iterator of type vector<MetaData> which points
                 * to the end of MetaData
                 *
                 */
                iterator end();

                /**
                 * constructor
                 */
                ResultSetMetaData();

                /**
                 * add a metadata item
                 * @param metaData the meta data item which should correspond to its
                 * tuple value
                 */
                void addMetaData(MetaData metaData);
            private:
                std::vector<MetaData> m_metaData;

        };
    }
}
#endif                                            // RESULTSETMETADATA_H
