/*
 *  Copyright (c) 2004 on behalf of the EU EGEE Project:
 *  The European Organization for Nuclear Research (CERN),
 *  Istituto Nazionale di Fisica Nucleare (INFN), Italy
 *  Datamat Spa, Italy
 *  Centre National de la Recherche Scientifique (CNRS), France
 *  CS Systeme d'Information (CSSI), France
 *  Royal Institute of Technology, Center for Parallel Computers (KTH-PDC), Sweden
 *  Universiteit van Amsterdam (UvA), Netherlands
 *  University of Helsinki (UH.HIP), Finland
 *  University of Bergen (UiB), Norway
 *  Council for the Central Laboratory of the Research Councils (CCLRC), United Kingdom
 */
#ifndef RGMA_SSLSOCKET_H
#define RGMA_SSLSOCKET_H
#define OPENSSL_NO_KRB5
#include "rgma/RGMAException.h"
#include "rgma/RemoteException.h"
#include "rgma/TCPSocket.h"
#include "rgma/SSLContext.h"
#include "log4cxx/logger.h"
#include "log4cxx/level.h"
#include "log4cxx/helpers/loglog.h"
#include "log4cxx/propertyconfigurator.h"
#include "log4cxx/helpers/exception.h"
#include <openssl/ssl.h>
#include <sys/socket.h>
#include <string>
namespace glite
{
    namespace rgma
    {
        /**
         * SSL socket wrapper
         * 
         */
        class SSLSocket :public TCPSocket
        {
            private:
                SSL* m_ssl;
                SSL_SESSION* m_sslSession;
                std::string m_host;
                int connectionCounter;
                const static int MAX_NO_OF_CONNECTIONS;
                int m_port;
                static SSLContext m_sslContext;
                log4cxx::LoggerPtr m_ssllogger;
                void establishSSL()throw(RGMAException, RemoteException);
                /**
                 * attempt to read from an established ssl conection
                 * returns 0 if ok, 1 if close notify and
                 *  2 if there is something else
                 */
                int sslPing(SSL *ssl, int socket);
                /**
                 * shut down the ssl connection and tcp connection remake the TCP connection
                 * re-establish the ssl connection
                 * 
                 */
                void reMakeSSLConnection() throw(RGMAException, RemoteException);
               
                
                void testRead(int returnCode) throw(RGMAException, RemoteException);

            public:
                virtual ~SSLSocket();
                SSLSocket();
                void connect(std::string host, int port) throw(RGMAException, RemoteException);
                void write(std::string request, std::string& resonse) throw(RGMAException, RemoteException);
                virtual void close()throw(RGMAException, RemoteException);
        };
    }
}
#endif
