#ifndef SECONDARYPRODUCERIMPL_H
#define SECONDARYPRODUCERIMPL_H
#include "rgma/ResourceEndpoint.h"
#include "rgma/TimeInterval.h"
#include "rgma/RemoteException.h"
#include "rgma/UnknownResourceException.h"
#include "rgma/RGMAException.h"
#include "rgma/Resource.h"
#include "rgma/ProducerProperties.h"
#include "rgma/SecondaryProducer.h"

#include <string>
namespace glite
{
    namespace rgma
    {
        /**
         * Implementation of a secondary producer
         */
        class SecondaryProducerImpl : public SecondaryProducer
        {
            private:
                void createProducer(TimeInterval terminationInterval,
                    ProducerProperties producerProperties) throw( RGMAException, RemoteException);

            public:
                /**
                 * @deprecated useSecondaryProducerImpl(ResourceEndpoint& endPoint)
                 *                   throw(RemoteException, RGMAException);
                 * */
                SecondaryProducerImpl(TimeInterval terminationInterval,
                    ProducerProperties producerProperties,
                    StringList voNames) throw( RGMAException);

                SecondaryProducerImpl(TimeInterval terminationInterval,
                    ProducerProperties producerProperties) throw( RGMAException, RemoteException);

                SecondaryProducerImpl(ResourceEndpoint& endPoint)
                    throw(RemoteException, RGMAException);

                virtual ~SecondaryProducerImpl(){}

                /**
                 * Gets the retention period that is applied to history tuples for the
                 * specified table.
                 *
                 * @param tableName Name of the table
                 *
                 * @return The retention period for history tuples.
                 *
                 * @throws RemoteException If the service could not be contacted.
                 * @throws UnknownResourceException If the resource could not be found.
                 * @throws RGMAException If the table has not been declared.
                 */
                TimeInterval getHistoryRetentionPeriod(std::string tableName)
                    throw(RemoteException, UnknownResourceException, RGMAException);

                /**
                 * Declares a table, specifying the retention period for history and latest
                 * tuples.  The latestRetentionPeriod specifies the time for which a
                 * latest tuple is valid.  After this time, the tuple is removed.  Tuples
                 * will be removed from storage when the history retention period expires.
                 *
                 * @param tableName The name of the table to declare.
                 * @param predicate An SQL WHERE clause defining the subset of a table that
                 *        this Producer will publish.  To publish to the whole table, an
                 *        empty predicate can be used.
                 * @param historyRetentionPeriod The retention period for history tuples
                 *
                 *
                 * @throws RemoteException If the service could not be contacted.
                 * @throws UnknownResourceException If the producer resource could not be
                 *         found
                 * @throws RGMAException If the tableName is unknown. If the predicate is
                 *         invalid. If either xxxRetentionPeriod is invalid.
                 */
                void declareTable(std::string tableName, std::string predicate,
                    TimeInterval historyRetentionPeriod)
                    throw(RemoteException, UnknownResourceException, RGMAException);

        };
    }
}
#endif
