/*
 *  Copyright (c) 2004 on behalf of the EU EGEE Project:
 *  The European Organization for Nuclear Research (CERN),
 *  Istituto Nazionale di Fisica Nucleare (INFN), Italy
 *  Datamat Spa, Italy
 *  Centre National de la Recherche Scientifique (CNRS), France
 *  CS Systeme d'Information (CSSI), France
 *  Royal Institute of Technology, Center for Parallel Computers (KTH-PDC), Sweden
 *  Universiteit van Amsterdam (UvA), Netherlands
 *  University of Helsinki (UH.HIP), Finland
 *  University of Bergen (UiB), Norway
 *  Council for the Central Laboratory of the Research Councils (CCLRC), United Kingdom
 */
#ifndef STRINGLIST_H
#define STRINGLIST_H
#include "rgma/RGMAException.h"
#include <vector>
#include <string>
namespace glite
{
    namespace rgma
    {
        /**
         * A list of String objects.
         */
        class StringList
        {
            public:

                StringList();
                virtual ~StringList();

                /**
                 * Add a String.
                 *
                 * @param string String to add.
                 */
                void addString(std::string string);
                /**
                 * Add a String at the specified index.
                 *
                 * @param index Index in list.
                 * @param string String to add.
                 */
                void addString(int index, std::string string)throw(RGMAException);
                /**
                 * Returns the size of the list.
                 *
                 * @return The number of Strings in the list.
                 */
                int size();
                /**
                 * Retrieves the String with the specified index.
                 *
                 * @param index Index of String to get (0 &lt;= index &lt; size)
                 *
                 * @return A pointer to a String object.
                 */
                std::string getString( int index );

            private:
                std::vector<std::string> m_strings;

        };
    }
}
#endif                                            // STRINGLIST_H
