/*
 *  Copyright (c) 2004 on behalf of the EU EGEE Project:
 *  The European Organization for Nuclear Research (CERN),
 *  Istituto Nazionale di Fisica Nucleare (INFN), Italy
 *  Datamat Spa, Italy
 *  Centre National de la Recherche Scientifique (CNRS), France
 *  CS Systeme d'Information (CSSI), France
 *  Royal Institute of Technology, Center for Parallel Computers (KTH-PDC), Sweden
 *  Universiteit van Amsterdam (UvA), Netherlands
 *  University of Helsinki (UH.HIP), Finland
 *  University of Bergen (UiB), Norway
 *  Council for the Central Laboratory of the Research Councils (CCLRC), United Kingdom
 */
#ifndef TABLEAUTHORIZATION_H
#define TABLEAUTHORIZATION_H
#include "rgma/StringList.h"
#include <string>
namespace glite
{
    namespace rgma
    {
        /**
         * Authorization rules for a table.
         */
        class TableAuthorization
        {
            private:
                StringList m_rules;

            public:

                TableAuthorization();
                virtual ~TableAuthorization();
                TableAuthorization( const TableAuthorization& auth );
                TableAuthorization& operator=(const TableAuthorization& auth  );
                /**
                 * Gets the number of rules in this TableAuthorization.
                 *
                 * @return The number of rules.
                 */
                int getNumRules() ;

                /**
                 * Gets the specified rule.
                 *
                 * @param ruleNum Number of the rule to retrieve.
                 *
                 * @return Specified rule.
                 */
                std::string getRule(int ruleNum);

                /**
                 * Adds a rule to this TableAuthorization.  A rule consists of a view on a
                 * table (a parameterized SELECT statement) and a set of allowed
                 * credentials specifying which users can access the view, separated by a
                 * colon.
                 *
                 * @param rule Rule
                 */
                void addRule(std::string rule);
        };
        std::ostream& operator<<( std::ostream& stream, TableAuthorization ta);
    }
}
#endif                                            // TABLEAUTHORIZATION_H
