/*
 *  Copyright (c) 2004 on behalf of the EU EGEE Project:
 *  The European Organization for Nuclear Research (CERN),
 *  Istituto Nazionale di Fisica Nucleare (INFN), Italy
 *  Datamat Spa, Italy
 *  Centre National de la Recherche Scientifique (CNRS), France
 *  CS Systeme d'Information (CSSI), France
 *  Royal Institute of Technology, Center for Parallel Computers (KTH-PDC), Sweden
 *  Universiteit van Amsterdam (UvA), Netherlands
 *  University of Helsinki (UH.HIP), Finland
 *  University of Bergen (UiB), Norway
 *  Council for the Central Laboratory of the Research Councils (CCLRC), United Kingdom
 */
#ifndef RGMA_TIMEINTERVAL_H
#define RGMA_TIMEINTERVAL_H

#include <string>
#include "rgma/RGMAException.h"
#include "rgma/Units.h"
namespace glite
{
    namespace rgma
    {
        /**
         * Encapsulates a time value and the units being used.
         */
        class TimeInterval
        {
            public:
                /**
                 *  A class that can represent a time interval
                 *
                 * @param value a long value
                 * @param units The time units: SECONDS, MINUTES, HOURS, DAYS
                 *
                 */
                TimeInterval( int value = 0, Units units = Units::SECONDS )
                    throw(RGMAException);
                virtual ~TimeInterval();

                /**
                 * creates a new TimeInterval object from the given TimeInterval
                 * @param timeInterval the timeInterval to be copied
                 *
                 */
                TimeInterval(const TimeInterval& timeInterval);

                TimeInterval& operator=(const TimeInterval& timeInterval);

                /**
                 * Gets the length of the time interval in the specified units.
                 *
                 * @param units The time units: SECONDS, MINUTES, HOURS, DAYS
                 *
                 * @return The time interval in the given units.
                 */
                int getValueAs(Units units) throw(RGMAException);

            private:
                int m_value;

        };
    }                                             //rgma
}                                                 //glite
#endif                                            //RGMA_TIMEINTERVAL_H
