/*
 *  Copyright (c) 2004 on behalf of the EU EGEE Project:
 *  The European Organization for Nuclear Research (CERN),
 *  Istituto Nazionale di Fisica Nucleare (INFN), Italy
 *  Datamat Spa, Italy
 *  Centre National de la Recherche Scientifique (CNRS), France
 *  CS Systeme d'Information (CSSI), France
 *  Royal Institute of Technology, Center for Parallel Computers (KTH-PDC), Sweden
 *  Universiteit van Amsterdam (UvA), Netherlands
 *  University of Helsinki (UH.HIP), Finland
 *  University of Bergen (UiB), Norway
 *  Council for the Central Laboratory of the Research Councils (CCLRC), United Kingdom
 */
#ifndef TUPLE_H
#define TUPLE_H
#include <vector>
#include <string>
#include "rgma/ResultSetMetaData.h"
#include "rgma/RGMAException.h"
namespace glite
{
    namespace rgma
    {
        /**
         *
         * A database tuple/row
         */
        class Tuple
        {

            public:
                /** class that stores the value of a tuple column and metadata
                 *  associated with the value, type. colum name and table name
                 * */
                class TupleItem
                {
                    private:
                        std::string m_value;
                        bool m_isNull;
                    public:
                        TupleItem(){}
                        /**
                         * Constructs a TupleItem
                         * @param value a stringified representation of the value
                         * @param isNull is the value NULL
                         */

                        TupleItem( std::string value = "", bool isNull = false);
                        /**
                         * is this tuple value SQL NULL
                         * @returns true if NULL otherwise false
                         */
                        bool isNull();
                        /**
                         * get the value of this item
                         * @returns the value as a string
                         */
                        std::string getValue();

                        virtual ~TupleItem();
                };

                Tuple(ResultSetMetaData& metaData);
                /**
                 *
                 * @deprecated use prefered constructor Tuple(ResultSetMetaData& metaData);
                 */
                Tuple(ResultSetMetaData* metaData);
                Tuple(){}
                virtual ~Tuple();

                Tuple( const Tuple& tuple );

                Tuple& operator=( const Tuple& tuple );

                /**
                 * Add an item to the list of TupleItems
                 * @param item
                 */
                void addTupleItem( TupleItem item );
                /**
                 *  get the result set meta data object
                 * @return the ResultSetMetaData object associated with this tuple
                 * @deprecated use getTupleMetaData()
                 */

                ResultSetMetaData* getMetaData();

                /**
                 *  get the result set meta data object
                 * @return the ResultSetMetaData object associated with this tuple
                 *
                 */
                ResultSetMetaData getTupleMetaData();

                /**
                 * get the value of a column as a double
                 * @param columnName the name of the coulmn
                 *
                 * @return the column value; if the value is SQL <code>NULL</code>, the
                 *         value returned is undefined use isNull to determine if NULL
                 */
                double getDouble( std::string columnName )throw(RGMAException);
                /**
                 * get the value of a column as a float
                 * @param columnName the name of the coulmn
                 *
                 * @return the column value; if the value is SQL <code>NULL</code>, the
                 *         value returned is undefined use isNull to determine if NULL
                 */
                float getFloat( std::string columnName )throw(RGMAException);
                /**
                 * get the value of a column as a string
                 * @param columnName the name of the coulmn
                 *
                 * @return the column value; if the value is SQL <code>NULL</code>
                 *          returned value is undefined use isNull to determine if NULL
                 */
                std::string getString( std::string columnName )throw(RGMAException);

                /**
                 * get the value of a column as a int
                 * @param columnName the name of the coulmn
                 *
                 * @return the column value; if the value is SQL <code>NULL</code> 
                 *      returned value is undefined use isNull to determine if NULL
                 */
                int getInt( std::string columnName )throw(RGMAException);

                /**
                 * get the value of a column as a bool
                 * @param columnName the name of the coulmn
                 *
                 * @return the column value; if the value is SQL <code>NULL</code>
                *  returned value is undefined use isNull to determine if NULL
                 */
                bool getBoolean( std::string columnName )throw(RGMAException);

                /**
                 *
                 * Is a value in the column null
                 *
                 *
                 * @return true if the value is SQL <code>0</code> else return false
                 */
                bool isNull(std::string columnName)throw(RGMAException);

            private:
                std::vector<TupleItem> m_items;
                ResultSetMetaData m_metaData;
                /**
                 * get the tuple item which corresponds to the column Name
                 * @param the columnName from which to get the value
                 *
                 */
                TupleItem getTupleItem(std::string columnName)throw(RGMAException);
        };
    }
}
#endif                                            // TUPLE_H
