#ifndef TupleStore_H
#define TupleStore_H

#include <string>
namespace glite
{
    namespace rgma
    {
        /**
         * Details of a named tuple store.
         */
        class TupleStore
        {
            public:
                TupleStore(bool isDatabase, bool isFile, bool isMemory, std::string logicalName, std::string location);
                ~TupleStore(){}
                /**
                 * Determines if this storage system is a database.
                 *
                 * @return True if the storage system is a database.
                 */
                bool isDatabase();

                /**
                 * Determines if this storage system is a file.
                 *
                 * @return True if the storage system is a file.
                 */
                bool isFile();

                /**
                 * Determines if this storage system is memory.
                 *
                 * @return True if the storage system is memory.
                 */
                bool isMemory();

                /**
                 * Gets the logical name for this storage system.
                 *
                 * @return Logical name as a String
                 */
                std::string getLogicalName();

                /**
                 * Gets the URL for this storage system.
                 *
                 * @return URL as a String
                 */
                std::string getLocation();
            private:
                bool m_isDatabase;
                bool m_isFile;
                bool m_isMemory;
                std::string m_logicalName;
                std::string m_location;
        };
        std::ostream& operator<<( std::ostream& stream, TupleStore ts);
    }
}
#endif
