/*
 *  Copyright (c) 2004 on behalf of the EU EGEE Project:
 *  The European Organization for Nuclear Research (CERN),
 *  Istituto Nazionale di Fisica Nucleare (INFN), Italy
 *  Datamat Spa, Italy
 *  Centre National de la Recherche Scientifique (CNRS), France
 *  CS Systeme d'Information (CSSI), France
 *  Royal Institute of Technology, Center for Parallel Computers (KTH-PDC), Sweden
 *  Universiteit van Amsterdam (UvA), Netherlands
 *  University of Helsinki (UH.HIP), Finland
 *  University of Bergen (UiB), Norway
 *  Council for the Central Laboratory of the Research Councils (CCLRC), United Kingdom
 */
#ifndef TYPES_H
#define TYPES_H
#include <map>
#include <string>
namespace glite
{
    namespace rgma
    {
        /**
         * Constants for SQL column types.
         */
        class Types
        {
            public:

                virtual ~Types();

                /**
                 * <P>
                 * The constant that identifies the generic SQL type <code>INTEGER</code>.
                 * </p>
                 */
                const static int INTEGER;

                /**
                 * <P>
                 * The constant that identifies the generic SQL type  <code>REAL</code>.
                 * </p>
                 */
                const static int REAL;

                /**
                 * <P>
                 * The constant that identifies the generic SQL type  <code>DOUBLE</code>.
                 * </p>
                 */
                const static int DOUBLE;

                /**
                 * <P>
                 * The constant that identifies the generic SQL type  <code>CHAR</code>.
                 * </p>
                 */
                const static int CHAR;

                /**
                 * <P>
                 * The constant that identifies the generic SQL type <code>VARCHAR</code>.
                 * </p>
                 */
                const static int VARCHAR;
                /**
                 * <P>
                 * The constant that identifies the generic SQL type <code>BOOLEAN</code>.
                 * </p>
                 */
                const static int BOOLEAN;

                /**
                 * <P>
                 * The constant that identifies the generic SQL type  <code>TIMESTAMP</code>.
                 * </p>
                 */
                const static int TIMESTAMP;
                /**
                 * <P>
                 * @deprecated
                 * The constant that identifies the generic SQL type  <code>DATE</code>.
                 * </p>
                 */
                const static int DATE;
                /**
                 * <P>
                 * The constant that identifies the generic SQL type  <code>TIME</code>.
                 * @deprecated
                 * </p>
                 */
                const static int TIME;
                /**
                 * Gets the name associated with a type number.
                 *
                 * @param type Type number.
                 *
                 * @return Name associated with <code>type</code>.
                 */
                static std::string getTypeName(int type);

            private:

                const static std::map<int,std::string> TYPE_NAMES;
        };

    }
}
#endif                                            // TYPES_H
