/*
 *  Copyright (c) 2004 on behalf of the EU EGEE Project:
 *  The European Organization for Nuclear Research (CERN),
 *  Istituto Nazionale di Fisica Nucleare (INFN), Italy
 *  Datamat Spa, Italy
 *  Centre National de la Recherche Scientifique (CNRS), France
 *  CS Systeme d'Information (CSSI), France
 *  Royal Institute of Technology, Center for Parallel Computers (KTH-PDC), Sweden
 *  Universiteit van Amsterdam (UvA), Netherlands
 *  University of Helsinki (UH.HIP), Finland
 *  University of Bergen (UiB), Norway
 *  Council for the Central Laboratory of the Research Councils (CCLRC), United Kingdom
 */
#ifndef URI_H
#define URI_H

#include "rgma/RGMAException.h"
#include <string>

namespace glite
{
    namespace rgma
    {
        /**
         *
         * A Class that provides some of the functionality to
         * enable compatibility with the Java API
         */
        class URI
        {
            private:
                std::string m_uri;
                short m_portNo;
                bool m_gotPort;

            public:
                virtual ~URI();
                /**
                 * parses a uri string into An URI object
                 * @param uri stringified version of a UII
                 * @throws RGMAException if an error occurs while parsing
                 */
                URI(const std::string uri = "")throw(RGMAException);
                /**
                 * parses a uri char* into An URI object
                 * @param newUri stringified version of a UII
                 * @throws RGMAException if an error occurs while parsing
                 */
                void set(const char* newUri)throw(RGMAException);
                /**
                 * Gets a stringified version of this URI
                 * @return  a stringified version of this URI
                 */
                std::string toString() const;
                /**
                 * Gets the host name
                 * @return  the host name
                 */
                std::string host() const;
                /**
                 * Gets the path
                 * @return  the path
                 */
                std::string path() const;
                /**
                 * Is the URI using Https
                 * @return  true if this URI is using https otherwise false
                 */
                bool usingHttps() const;
                /**
                 * Get the port
                 * @return  the port number
                 */
                short port();
        };
        std::ostream& operator<<( std::ostream& stream, URI uri );
    }
}
#endif                                            // URI_H
