/*
 *  Copyright (c) 2004 on behalf of the EU EGEE Project:
 *  The European Organization for Nuclear Research (CERN),
 *  Istituto Nazionale di Fisica Nucleare (INFN), Italy
 *  Datamat Spa, Italy
 *  Centre National de la Recherche Scientifique (CNRS), France
 *  CS Systeme d'Information (CSSI), France
 *  Royal Institute of Technology, Center for Parallel Computers (KTH-PDC), Sweden
 *  Universiteit van Amsterdam (UvA), Netherlands
 *  University of Helsinki (UH.HIP), Finland
 *  University of Bergen (UiB), Norway
 *  Council for the Central Laboratory of the Research Councils (CCLRC), United Kingdom
 */
#ifndef UNITS_H
#define UNITS_H
//#include "rgma/TimeInterval.h"
namespace glite
{
    namespace rgma
    {
        /**
         * Time units.
         */
        class Units
        {
            friend class TimeInterval;
            private:
                /** Seconds. */
                const static int S = 0;

                /** Minutes. */
                const static int M = 1;

                /** Hours. */
                const static int H = 2;

                /** Days. */
                const static int D = 3;
                const static  long* RATIOS;
                int m_units;

            protected:
                /**
                 * Constructs a Units object.
                 *
                 * @param units An <code>int</code> representing the units to use.
                 */
                Units(int units);
                /**
                 * Gets the number of seconds in this unit.
                 *
                 * @return The number of seconds in one of this unit.
                 */
                long getNumSeconds();

                /**
                 * Gets the units represented by this Units object.
                 *
                 * @return An <code>int</code> representing the units, one of
                 *         S (second), M (minute), H (hour) or D (day).
                 */
                int getUnits();

            public:
                Units(){}
                virtual ~Units();
                /** Seconds. */
                const static Units SECONDS;

                /** Minutes. */
                const static Units MINUTES;

                /** Hours. */
                const static Units HOURS;

                /** Days. */
                const static Units DAYS;

                /**
                 * Compares this Units object with another.
                 *
                 * @param units The other Units object.
                 *
                 * @return True if they represent the same units.
                 */
                bool equals(Units units);

                /**
                 * Returns a hash code value for the object.
                 *
                 * @return a hash code value for this object.
                 */
                int hashCode();

        };
    }
}
#endif                                            // UNITS_H
